@@ -21,7 +21,8 @@ import itertools
 import collections
 
 __author__  = 'Miguel Turner'
-__version__ = '0.2.6'
+__version__ = '0.2.7'
+__license__ = 'MIT'
 
 __all__ = [
     'Config',
@@ -160,7 +161,6 @@ class ConfigSection(collections.MutableMapping):
         """Initializes a key to the given default value. If *type* is not
         provided, the type of the default value will be used."""
         section = self._create_section(key)
-        section._value = NoValue
         section._cache = NoValue
         section._type = type or default.__class__
         section._has_type = True
@@ -195,6 +195,12 @@ class ConfigSection(collections.MutableMapping):
         section = self.section(key)
         del section._parent._children[section.name]
     
+    def __bool__(self):
+        return True
+    
+    def __nonzero__(self):
+        return True
+    
     def __len__(self):
         return len(self._children)
     
@@ -320,7 +326,7 @@ class ConfigSection(collections.MutableMapping):
         elif type is None and self._cache is not NoValue:
             return self._cache
         elif self._value is not NoValue:
-            value = self._convert(self._value, type)
+            value = self.convert(self._value, type)
             self._cache = self._cache_value(value)
             return value
         
@@ -329,7 +335,7 @@ class ConfigSection(collections.MutableMapping):
     def set_value(self, value):
         """Set the section's value."""
         if not isinstance(value, str):
-            strvalue = self._adapt(value)
+            strvalue = self.adapt(value)
             if strvalue != self._value:
                 self._value = strvalue
                 self._cache = self._cache_value(value)
@@ -354,7 +360,7 @@ class ConfigSection(collections.MutableMapping):
                 # only use cache if self._value hasn't been set
                 return self._cache
             else:
-                value = self._convert(self._default, type)
+                value = self.convert(self._default, type)
                 # only set cache if self._value hasn't been set
                 if self._value is NoValue:
                     self._cache = self._cache_value(value)
@@ -367,7 +373,7 @@ class ConfigSection(collections.MutableMapping):
         Set the section's default value.
         """
         if not isinstance(default, str):
-            self._default = self._adapt(default)
+            self._default = self.adapt(default)
             # only set cache if self._value hasn't been set
             if self._value is NoValue:
                 self._cache = self._cache_value(default)
@@ -383,11 +389,19 @@ class ConfigSection(collections.MutableMapping):
         for key in self:
             yield (key, self.section(key).value(convert))
     
-    def adapt(self, value, type):
-        return self._root.coercer.adapt(value, type)
+    def adapt(self, value):
+        if self._root.coerce_values:
+            if not self._has_type:
+                self._type = value.__class__
+            return self._root.coercer.adapt(value, self._type)
+        else:
+            return value
     
     def convert(self, value, type):
-        return self._root.coercer.convert(value, type)
+        if self._root.coerce_values:
+            return self._root.coercer.convert(value, type or self._type)
+        else:
+            return value
     
     def clear_cache(self, recurse=False):
         """Clears cached values for this section. If *recurse* is
@@ -402,7 +416,10 @@ class ConfigSection(collections.MutableMapping):
         
         # read unchanged values from sources
         for i, source in enumerate(reversed(sources)):
-            file = format.open(source)
+            try:
+                file = format.open(source)
+            except IOError:
+                continue
             
             # read file
             try:
@@ -522,23 +539,9 @@ class ConfigSection(collections.MutableMapping):
             if self._default is NoValue:
                 self._type = None
     
-    def _adapt(self, value):
-        if self._root.coerce_values:
-            if not self._has_type:
-                self._type = value.__class__
-            return self.adapt(value, self._type)
-        else:
-            return value
-    
-    def _convert(self, value, type=None):
-        if self._root.coerce_values:
-            return self.convert(value, type or self._type)
-        else:
-            return value
-    
     def _adapt_cache(self):
         if self._cache is not NoValue:
-            strvalue = self._adapt(self._cache)
+            strvalue = self.adapt(self._cache)
             if strvalue != self.value(convert=False):
                 self.set_value(strvalue)
                 self._dirty = True
@@ -770,18 +773,18 @@ class IniFormat(Format):
         lines = []
         for i, orgline in enumerate(file, 1):
             line = orgline.strip()
-            if not line or line.startswith('#'):
+            if not line or line.startswith(';'):
                 # blank or comment line
                 lines.append((orgline, False, False))
                 continue
-            else:
-                match = IniFormat._rx_section_header.match(line)
-                if match:
-                    section = match.group(1)
-                    if section.lower() == 'default':
-                        section = ''
-                    lines.append(((section, orgline), False, True))
-                    continue
+            
+            match = IniFormat._rx_section_header.match(line)
+            if match:
+                section = match.group(1)
+                if section.lower() == 'default':
+                    section = ''
+                lines.append(((section, orgline), False, True))
+                continue
             
             if section is None:
                 self._read_error(file, i, line)
@@ -838,7 +841,7 @@ class IniFormat(Format):
                         for key, value in sec.items():
                             if section:
                                 key = stripbase(key)
-                            file.write('{} = {}\n'.format(key, value))
+                            file.write('{}={}\n'.format(key, value))
                         del sections[section]
                         file.write('\n')
                 # new section
@@ -864,7 +867,7 @@ class IniFormat(Format):
                     wkey = key
                     if section:
                         wkey = stripbase(key)
-                    line = '{} = {}\n'.format(wkey, values[key])
+                    line = '{}={}\n'.format(wkey, values[key])
                     del sec[key]
                     if not sec:
                         del sections[section]
@@ -872,15 +875,18 @@ class IniFormat(Format):
         
         # write remaining values
         if sections:
-            last = section
-            end = list(sections.keys())[-1]
-            for section, values in sections.items():
+            last = None
+            key = lambda item: (item[0] == 'DEFAULT', item[0])
+            sects = sorted(sections.items(), key=key)
+            end = sects[-1][0]
+            for section, values in sects:
                 if section != last:
                     file.write('[{}]\n'.format(section or 'DEFAULT'))
+                    last = section
                 for key, value in values.items():
                     if section:
                         key = stripbase(key)
-                    line = '{} = {}\n'.format(key, value)
+                    line = '{}={}\n'.format(key, value)
                     file.write(line)
                 if section != end:
                     file.write('\n')
@@ -998,11 +1004,6 @@ class Coercer:
     The coercer class, with which adapters and converters can be registered.
     """
     def __init__(self, register_defaults=True, register_qt=None):
-        #: An adapter to fallback to when no other adapter is found.
-        self.adapt_fallback = None
-        #: An converter to fallback to when no other converter is found.
-        self.convert_fallback = None
-        
         self._adapters = {}
         self._converters = {}
         
@@ -1017,98 +1018,34 @@ class Coercer:
     def adapt(self, value, type=None):
         """Adapt a *value* from the given *type* (type to string). If
         *type* is not provided the type of the value will be used."""
+        
         if not type:
             type = _type(value)
         
-        if isinstance(type, tuple):
-            try:
-                try:
-                    # try and get an adapter for the full type sequence
-                    seq_adapter = self._get_adapter(type)
-                except KeyError:
-                    # otherwise use the first type to get the adapter
-                    seq_adapter = self._get_adapter(type[0])
-                
-                # str is default if no other type is given
-                seq_types = type[1:]
-                if not seq_types:
-                    seq_types = [str]
-                
-                ads = itertools.cycle(self._get_adapter(t) for t in seq_types)
-            except KeyError:
-                # fallback
-                pass
-            else:
-                try:
-                    return seq_adapter(next(ads)(v) for v in value)
-                except Exception as e:
-                    raise AdaptError(e)
-        else:
-            try:
-                func = self._get_adapter(type)
-            except KeyError:
-                # fallback
-                pass
-            else:
-                try:
-                    return func(value)
-                except Exception as e:
-                    raise AdaptError(e)
-        
-        if self.adapt_fallback:
-            try:
-                return self.adapt_fallback(value)
-            except Exception as e:
-                raise AdaptError(e)
-        else:
-            err = "no adapter registered for '{}'"
+        try:
+            func = self._adapters[self._typename(type)]
+        except KeyError:
+            err = 'no adapter for: {}'
             raise NotRegisteredError(err.format(type))
+        
+        try:
+            return func(value)
+        except Exception as e:
+            raise AdaptError(e)
     
     def convert(self, value, type):
         """Convert a *value* to the given *type* (string to type)."""
-        if isinstance(type, tuple):
-            try:
-                try:
-                    # try and get a converter for the full type sequence
-                    seq_converter = self._get_converter(type)
-                except KeyError:
-                    # otherwise try the first type to get the converter
-                    seq_converter = self._get_converter(type[0])
-                
-                # str is default if no other type is given
-                seq_types = type[1:]
-                if not seq_types:
-                    seq_types = [str]
-                
-                cons = itertools.cycle(self._get_converter(t) for t in seq_types)
-            except KeyError:
-                # fallback
-                pass
-            else:
-                try:
-                    return type[0](next(cons)(v) for v in seq_converter(value))
-                except Exception as e:
-                    raise ConvertError(e)
-        else:
-            try:
-                func = self._get_converter(type)
-            except KeyError:
-                # fallback
-                pass
-            else:
-                try:
-                    return func(value)
-                except Exception as e:
-                    raise ConvertError(e)
         
-        if self.convert_fallback:
-            try:
-                return self.convert_fallback(value)
-            except Exception as e:
-                raise ConvertError(e)
-        else:
-            err = "no converter registered for '{}'"
+        try:
+            func = self._converters[self._typename(type)]
+        except KeyError:
+            err = "no converter for: {}"
             raise NotRegisteredError(err.format(type))
+        
+        try:
+            return func(value)
+        except Exception as e:
+            raise ConvertError(e)
     
     def register(self, type, adapter, converter):
         """Register an adapter and converter for the given type."""
@@ -1143,6 +1080,8 @@ class Coercer:
         self.register_converter(type, convert)
     
     def _typename(self, type):
+        if isinstance(type, bytes):
+            type = type.decode('utf-8')
         if isinstance(type, str):
             if '.' in type:
                 return tuple(type.rsplit('.', 1))
@@ -1158,12 +1097,6 @@ class Coercer:
         else:
             t = _type(type)
             return (t.__module__, t.__name__)
-    
-    def _get_adapter(self, type):
-        return self._adapters[self._typename(type)]
-    
-    def _get_converter(self, type):
-        return self._converters[self._typename(type)]
 
 ## Coercer Errors ##
 
@@ -1203,19 +1136,13 @@ def register_default_coercers(coercer):
     coercer.register(list, lambda x: ','.join(x), split)
     coercer.register(set, lambda x: ','.join(x), lambda x: set(split(x)))
     coercer.register(tuple, lambda x: ','.join(x), lambda x: tuple(split(x)))
-    coercer.register(collections.deque, lambda x: ','.join(x),
-        lambda x: collections.deque(split(x)))
     
     # path coercers, os.pathsep delimited
-    coercer.register('path', str, str)
     sep = os.pathsep
     pathsplit = lambda x: x.split(sep) if x else []
-    coercer.register((list, 'path'), lambda x: sep.join(x), pathsplit)
-    coercer.register((set, 'path'), lambda x: sep.join(x), lambda x: set(pathsplit(x)))
-    coercer.register((tuple, 'path'), lambda x: sep.join(x),
-        lambda x: tuple(pathsplit(x)))
-    coercer.register((collections.deque, 'path'), lambda x: sep.join(x),
-        lambda x: collections.deque(pathsplit(x)))
+    coercer.register('path_list', lambda x: sep.join(x), pathsplit)
+    coercer.register('path_set', lambda x: sep.join(x), lambda x: set(pathsplit(x)))
+    coercer.register('path_tuple', lambda x: sep.join(x), lambda x: tuple(pathsplit(x)))
 
 def register_booleans(coercer):
     ## override boolean coercers ##
